# API Reference

## Multi-convention

<!-- prettier-ignore -->
::: zarr_cm
    options:
      members:
        - CONVENTION_NAMES
        - ALL_CONVENTION_KEYS
        - MultiConventionAttrs
        - create_many
        - validate_many
        - validate_all
        - insert_many
        - extract_many
        - extract_all

## Core

<!-- prettier-ignore -->
::: zarr_cm._core

## geo-proj

::: zarr_cm.geo_proj

## spatial

::: zarr_cm.spatial

## multiscales

::: zarr_cm.multiscales

## license

::: zarr_cm.license

## uom

::: zarr_cm.uom
